[Xorg-commit] xc/lib/font/Type1 scanfont.c,1.1.4.2,1.1.4.3

Kaleb Keithley xserver-commit at pdx.freedesktop.org
Sat Dec 6 15:24:55 EET 2003


Committed by: kaleb

Update of /cvs/xorg/xc/lib/font/Type1
In directory pdx:/home/kaleb/xorg/xc.XORG-CURRENT/lib/font/Type1

Modified Files:
      Tag: XORG-CURRENT
	scanfont.c 
Log Message:
merge XFree86 4.3.99.901 (RC1) from vendor branch

Index: scanfont.c
===================================================================
RCS file: /cvs/xorg/xc/lib/font/Type1/scanfont.c,v
retrieving revision 1.1.4.2
retrieving revision 1.1.4.3
diff -u -d -r1.1.4.2 -r1.1.4.3
--- scanfont.c	26 Nov 2003 22:48:40 -0000	1.1.4.2
+++ scanfont.c	6 Dec 2003 13:24:22 -0000	1.1.4.3
@@ -1,3 +1,4 @@
+/* $XdotOrg$ */
 /* $Xorg: scanfont.c,v 1.3 2000/08/17 19:46:32 cpqbld Exp $ */
 /* Copyright International Business Machines,Corp. 1991
  * All Rights Reserved
@@ -45,7 +46,7 @@
  * The Original Software is CID font code that was developed by Silicon
  * Graphics, Inc.
  */
-/* $XFree86: xc/lib/font/Type1/scanfont.c,v 1.16 2003/05/27 22:26:46 tsi Exp $ */
+/* $XFree86: xc/lib/font/Type1/scanfont.c,v 1.17 2003/11/29 04:55:28 dawes Exp $ */
 
 #ifndef FONTMODULE
 #include <string.h>
@@ -1727,8 +1728,9 @@
         tokenStartP[tokenLength] = '\0';
 
         rc = FindDictValue(CMapP->CMapInfoP);
-        /* we are not going to report errors */
-        rc = SCAN_OK;
+        /* we are not going to report errors except out of memory */
+        if (rc != SCAN_OUT_OF_MEMORY)
+          rc = SCAN_OK;
         break;
       case TOKEN_NAME:
         if (0 == strncmp(tokenStartP,"begincodespacerange",19)) {
@@ -1983,8 +1985,9 @@
 
          if (CIDWantFontInfo) {
              rc = FindDictValue(CIDFontP->CIDfontInfoP);
-             /* we are not going to report errors */
-             rc = SCAN_OK;
+             /* we are not going to report errors except out of memory */
+             if (rc != SCAN_OUT_OF_MEMORY)
+               rc = SCAN_OK;
              break;
          }
         break;
@@ -2109,8 +2112,10 @@
               /* same UniqueID.  We would faile on /UniqueID get  */
               /* because we are expecting a int to follow UniqueID*/
               /* If the correct object type does not follow a Name*/
-              /* then we will skip over it without reporting error*/
-              rc = SCAN_OK;
+              /* then we will skip over it without reporting error except */
+              /* out of memory */
+              if (rc != SCAN_OUT_OF_MEMORY)
+                rc = SCAN_OK;
               break;
             }   /* end of reading Private dictionary */
             else
@@ -2122,8 +2127,9 @@
               else
                 if (WantFontInfo) {
                   rc = FindDictValue(FontP->fontInfoP);
-                  /* we are not going to report errors */
-                  rc = SCAN_OK;
+                  /* we are not going to report errors except out of memory */
+                  if (rc != SCAN_OUT_OF_MEMORY)
+                    rc = SCAN_OK;
                   break;
                 }
         break;
@@ -2298,8 +2304,10 @@
               /* same UniqueID.  We would faile on /UniqueID get  */
               /* because we are expecting a int to follow UniqueID*/
               /* If the correct object type does not follow a Name*/
-              /* then we will skip over it without reporting error*/
-              rc = SCAN_OK;
+              /* then we will skip over it without reporting error except */
+              /* when out of memory */
+              if (rc != SCAN_OUT_OF_MEMORY)
+                rc = SCAN_OK;
               break;
             }   /* end of reading Private dictionary */
             else
@@ -2311,8 +2319,9 @@
               else
                 if (WantFontInfo) {
                   rc = FindDictValue(FontP->fontInfoP);
-                  /* we are not going to report errors */
-                  rc = SCAN_OK;
+                  /* we are not going to report errors except out of memory */
+                  if (rc != SCAN_OUT_OF_MEMORY)
+                    rc = SCAN_OK;
                   break;
                 }
         break;





More information about the xorg-commit mailing list